@@ -1,5 +1,11 @@
+# -*- coding: utf-8 -*-
+
+import logging
+
 from requests.exceptions import HTTPError
 
+log = logging.getLogger(__name__)
+
 
 # Query errors
 class InvalidDate(ValueError):
